@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.845';
+our $VERSION = '1.846';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -716,7 +716,7 @@ MCE::Step - Parallel step model for building creative steps
 
 =head1 VERSION
 
-This document describes MCE::Step version 1.845
+This document describes MCE::Step version 1.846
 
 =head1 DESCRIPTION
 
@@ -981,7 +981,7 @@ The following list options which may be overridden when loading the module.
  ;
 
 From MCE 1.8 onwards, Sereal 3.015+ is loaded automatically if available.
-Specify C<Sereal => 0> to use Storable instead.
+Specify C<< Sereal => 0 >> to use Storable instead.
 
  use MCE::Step Sereal => 0;
 
